# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: persist.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rpersist.proto\x12\x07persist\";\n\x12\x46\x65\x61tureGroupSchema\x12\r\n\x05label\x18\x01 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_labels\x18\x02 \x03(\t\"J\n\x04\x44\x61ta\x12\x12\n\nkey_values\x18\x01 \x03(\t\x12.\n\x0e\x66\x65\x61ture_values\x18\x02 \x03(\x0b\x32\x16.persist.FeatureValues\"0\n\rFeatureValues\x12\x1f\n\x06values\x18\x01 \x01(\x0b\x32\x0f.persist.Values\"\xd9\x01\n\x06Values\x12\x13\n\x0b\x66p32_values\x18\x01 \x03(\x01\x12\x13\n\x0b\x66p64_values\x18\x02 \x03(\x01\x12\x14\n\x0cint32_values\x18\x03 \x03(\x05\x12\x14\n\x0cint64_values\x18\x04 \x03(\x03\x12\x15\n\ruint32_values\x18\x05 \x03(\r\x12\x15\n\ruint64_values\x18\x06 \x03(\x04\x12\x15\n\rstring_values\x18\x07 \x03(\t\x12\x13\n\x0b\x62ool_values\x18\x08 \x03(\x08\x12\x1f\n\x06vector\x18\t \x03(\x0b\x32\x0f.persist.Vector\")\n\x06Vector\x12\x1f\n\x06values\x18\x01 \x01(\x0b\x32\x0f.persist.Values\"\x8a\x01\n\x05Query\x12\x14\n\x0c\x65ntity_label\x18\x01 \x01(\t\x12\x13\n\x0bkeys_schema\x18\x02 \x03(\t\x12\x39\n\x14\x66\x65\x61ture_group_schema\x18\x03 \x03(\x0b\x32\x1b.persist.FeatureGroupSchema\x12\x1b\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\r.persist.Data\"\x19\n\x06Result\x12\x0f\n\x07message\x18\x02 \x01(\t2F\n\x0e\x46\x65\x61tureService\x12\x34\n\x0fPersistFeatures\x12\x0e.persist.Query\x1a\x0f.persist.Result\"\x00\x42\x0cZ\n../persistb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'persist_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n../persist'
  _FEATUREGROUPSCHEMA._serialized_start=26
  _FEATUREGROUPSCHEMA._serialized_end=85
  _DATA._serialized_start=87
  _DATA._serialized_end=161
  _FEATUREVALUES._serialized_start=163
  _FEATUREVALUES._serialized_end=211
  _VALUES._serialized_start=214
  _VALUES._serialized_end=431
  _VECTOR._serialized_start=433
  _VECTOR._serialized_end=474
  _QUERY._serialized_start=477
  _QUERY._serialized_end=615
  _RESULT._serialized_start=617
  _RESULT._serialized_end=642
  _FEATURESERVICE._serialized_start=644
  _FEATURESERVICE._serialized_end=714
# @@protoc_insertion_point(module_scope)
