# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: retrieve.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eretrieve.proto\x12\x08retrieve\"\x14\n\x04Keys\x12\x0c\n\x04\x63ols\x18\x01 \x03(\t\"\x80\x01\n\x05Query\x12\x14\n\x0c\x65ntity_label\x18\x01 \x01(\t\x12.\n\x0e\x66\x65\x61ture_groups\x18\x02 \x03(\x0b\x32\x16.retrieve.FeatureGroup\x12\x13\n\x0bkeys_schema\x18\x03 \x03(\t\x12\x1c\n\x04keys\x18\x04 \x03(\x0b\x32\x0e.retrieve.Keys\",\n\x07\x46\x65\x61ture\x12\r\n\x05label\x18\x01 \x01(\t\x12\x12\n\ncolumn_idx\x18\x02 \x01(\x05\"Q\n\rFeatureSchema\x12\x1b\n\x13\x66\x65\x61ture_group_label\x18\x01 \x01(\t\x12#\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32\x11.retrieve.Feature\"$\n\x03Row\x12\x0c\n\x04keys\x18\x01 \x03(\t\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\x0c\"\x82\x01\n\x06Result\x12\x14\n\x0c\x65ntity_label\x18\x01 \x01(\t\x12\x13\n\x0bkeys_schema\x18\x02 \x03(\t\x12\x30\n\x0f\x66\x65\x61ture_schemas\x18\x03 \x03(\x0b\x32\x17.retrieve.FeatureSchema\x12\x1b\n\x04rows\x18\x04 \x03(\x0b\x32\r.retrieve.Row\"z\n\rDecodedResult\x12\x13\n\x0bkeys_schema\x18\x01 \x03(\t\x12\x30\n\x0f\x66\x65\x61ture_schemas\x18\x02 \x03(\x0b\x32\x17.retrieve.FeatureSchema\x12\"\n\x04rows\x18\x03 \x03(\x0b\x32\x14.retrieve.DecodedRow\"+\n\nDecodedRow\x12\x0c\n\x04keys\x18\x01 \x03(\t\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\"5\n\x0c\x46\x65\x61tureGroup\x12\r\n\x05label\x18\x01 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_labels\x18\x02 \x03(\t2\x8e\x01\n\x0e\x46\x65\x61tureService\x12\x37\n\x10RetrieveFeatures\x12\x0f.retrieve.Query\x1a\x10.retrieve.Result\"\x00\x12\x43\n\x15RetrieveDecodedResult\x12\x0f.retrieve.Query\x1a\x17.retrieve.DecodedResult\"\x00\x42\rZ\x0b../retrieveb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'retrieve_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\013../retrieve'
  _KEYS._serialized_start=28
  _KEYS._serialized_end=48
  _QUERY._serialized_start=51
  _QUERY._serialized_end=179
  _FEATURE._serialized_start=181
  _FEATURE._serialized_end=225
  _FEATURESCHEMA._serialized_start=227
  _FEATURESCHEMA._serialized_end=308
  _ROW._serialized_start=310
  _ROW._serialized_end=346
  _RESULT._serialized_start=349
  _RESULT._serialized_end=479
  _DECODEDRESULT._serialized_start=481
  _DECODEDRESULT._serialized_end=603
  _DECODEDROW._serialized_start=605
  _DECODEDROW._serialized_end=648
  _FEATUREGROUP._serialized_start=650
  _FEATUREGROUP._serialized_end=703
  _FEATURESERVICE._serialized_start=706
  _FEATURESERVICE._serialized_end=848
# @@protoc_insertion_point(module_scope)
